summaryrefslogtreecommitdiff
path: root/mpn/vax/lshift.s
diff options
context:
space:
mode:
Diffstat (limited to 'mpn/vax/lshift.s')
-rw-r--r--mpn/vax/lshift.s6
1 files changed, 3 insertions, 3 deletions
diff --git a/mpn/vax/lshift.s b/mpn/vax/lshift.s
index 7b9942df9..b870fc7c1 100644
--- a/mpn/vax/lshift.s
+++ b/mpn/vax/lshift.s
@@ -1,4 +1,4 @@
# VAX __mpn_lshift -- left shift.
# Copyright (C) 1999 Free Software Foundation, Inc.
@@ -30,8 +30,8 @@
.text
.align 1
-.globl ___mpn_lshift
-___mpn_lshift:
+.globl ___gmpn_lshift
+___gmpn_lshift:
.word 0x1c0
movl 4(ap),r7
movl 8(ap),r6
@@ -1,4 +1,4 @@
-# VAX __mpn_lshift -- left shift.
+# VAX __gmpn_lshift -- left shift.
# Copyright (C) 1999 Free Software Foundation, Inc.